[Libreoffice-commits] core.git: vcl/unx

Caolán McNamara (via logerrit) logerrit at kemper.freedesktop.org
Tue Jun 15 13:01:33 UTC 2021


 vcl/unx/gtk4/convert3to4.cxx |    5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

New commits:
commit d2f0a09c39f87a85a49844edefe304a5cdb9f0dd
Author:     Caolán McNamara <caolanm at redhat.com>
AuthorDate: Tue Jun 15 11:52:11 2021 +0100
Commit:     Caolán McNamara <caolanm at redhat.com>
CommitDate: Tue Jun 15 15:00:46 2021 +0200

    gtk4: leave Help button unchanged if its in a GtkMessageDialog
    
    as opposed to a help button which will be relocated to the titlebar
    
    Change-Id: I2053ad05025cce9e0a894b555160b56eb5bc2f6b
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/117239
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caolanm at redhat.com>

diff --git a/vcl/unx/gtk4/convert3to4.cxx b/vcl/unx/gtk4/convert3to4.cxx
index cbec6f838c8a..9572f7fb07ec 100644
--- a/vcl/unx/gtk4/convert3to4.cxx
+++ b/vcl/unx/gtk4/convert3to4.cxx
@@ -469,8 +469,9 @@ ConvertResult Convert3To4(const css::uno::Reference<css::xml::dom::XNode>& xNode
                 }
             }
 
-            // remove 'Help' button label and replace with a help icon instead
-            if (sName == "label" && GetParentObjectType(xChild) == "GtkButton")
+            // remove 'Help' button label and replace with a help icon instead. Unless the toplevel is a message dialog
+            if (sName == "label" && GetParentObjectType(xChild) == "GtkButton"
+                && !ToplevelIsMessageDialog(xChild))
             {
                 css::uno::Reference<css::xml::dom::XNamedNodeMap> xParentMap
                     = xChild->getParentNode()->getAttributes();


More information about the Libreoffice-commits mailing list